==> igloo_0_1_2.tar.tgz: igloo_0_1_2/igloo/template/barnraiser_01/sn_list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>




<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_social_network'];?><br />
		</div>

		<div class="box_mid">
			<div class="content">
				<table width="100%" border="0" cellspacing="0" cellpadding="4">
					<?php
					if (isset($users)) {
					foreach($users as $key => $i):
					?>
					
					<tr>
						<td valign="top" width="32" rowspan="2">
							<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
						</td>
							
						<td valign="middle">
							<?php
							if (!empty($i['am_relation_to_them']['relation_show_true_self'])) {
							?>
								<b><a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><?php echo $i['user_firstname']. " " . $i['user_surname'];?></a></b>,
								
								
								<?php echo $i['user_create_datetime'];?>,
								<?php echo $i['user_hometown'];?>,
							<?php
							}
							else {
							?>
							
								<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><b><?php echo $i['profile_nic'];?></b></a>,
								
								
								<?php echo $i['user_create_datetime'];?>,
								<?php echo $i['profile_hometown'];?>,
							<?php }?>
							
							<?php
							if ($i['online_status'] == 1) {
								echo "<b>" . $lang['arr_user_online_status'][1] . "</b><br />";
							}
							else {
									echo $lang['arr_user_online_status'][$i['online_status']] . "<br />";
							}
							?>
						</td>
						
						<td valign="top" width="80">
							<?php
							if (isset($i['relation_to'])) {
								echo "<img src='" . $templatePath . "img/sn_connected_to_them.png' width='16' height='16' title='" .  $lang['txt_help_icon_conn'] . "' alt='" .  $lang['txt_help_icon_conn'] . "' />&nbsp;";
								
								if (!empty($i['relation_to']['relation_show_network'])) {
									echo "<img src='" . $templatePath . "img/sn_they_see_my_nw.png' width='16' height='16' title='" . $lang['txt_help_icon_net'] . "' alt='" . $lang['txt_help_icon_net'] . "' />&nbsp;";
								}
								
								if (!empty($i['relation_to']['relation_show_true_self'])) {
									echo "<img src='" . $templatePath . "img/sn_true_self_revealed_to_them.png' width='16' height='16' title='" . $lang['txt_help_icon_ts'] . "' alt='" . $lang['txt_help_icon_ts'] . "' />&nbsp;";
								}
							}
							?><br />
						</td>
						<td align="right" rowspan="2">
							<?php
							if (isset($i['profile_allow_msg']) && $i['profile_allow_msg'] == 1) {
							?>
							<a href="msg_compose.php?to_user_id=<?php echo $i['user_id'];?>"><img src="<?php echo $templatePath;?>img/unopenned_mail.png" title="<?php echo $lang['ttl_send_message'];?>" border="0" alt="" /></a>&nbsp;&nbsp;<br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td>
							<p>
								<?php echo $lang['txt_tag'];?>: 
		
								<?php
								$tags = "";
								if (isset($i['tags'])) {
									foreach ($i['tags'] as $keyt => $t):
										$tags .= $t['tag_body'];
										
										if (count($i['tags']) > $keyt+1) {
											$tags .= ", ";
										}
									endforeach;
									echo $tags;
								}
								?>
							</p>
						</td>
						<td>
							<?php
							if (!empty($i['blocked'])) {
								echo $lang['txt_blocked'] . "<br />";
							}
							?>
							<?php
							if (!empty($i['am_relation_to_them']['relation_show_network'])) {
									echo "relations: " . $i['sn_total'];
								}
							?>
							<br />
						</td>
					</tr>
					<tr>
						<td colspan="4">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					}
					else {
					?>
					<tr>
						<td colspan="4">
							<?php echo $lang['err_no_people'];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
				
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
				
				<table cellpadding="4" cellspacing="0" border="0">
					<tr>
						<td colspan="2">
							<b><?php echo $lang['hdr_im_pending'];?></b><br />
						</td>
					</tr>
					<?php
					if (isset($pending)) {
					foreach($pending as $key => $i):
					?>
					<tr>
						<td>
							<?php echo $this->date->formatDate($i['invite_create_datetime']);?><br />
						</td>
						<td>
							<?php echo $i['email'];?><br />
						</td>
					</tr>
					<?php
					endforeach;
					} else {
					?>
					<tr>
						<td colspan="2">
							<?php echo $lang['err_no_pending_requests'];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_statistics'];?><br />
		</div>

		<div class="box_mid">
			<div class="content">
				<table width="100%" border="0" cellspacing="0" cellpadding="4">
					<tr>
						<td valign="top">
							<b><?php echo $lang['txt_social_network'];?></b><br />
							<?php echo $lang['txt_social_network_intro'];?>
						</td>
					</tr>
				</table>
	
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
	
				<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture_light">
					<?php
					if (isset($sn_statistics['degrees'])) {
	
					foreach($sn_statistics['degrees'] as $key => $i):
					?>
					<tr>
						<td class="bg3">
							<?php echo $lang['sn']['degree'][$i['degree_id']];?><br />
							<span class="txt_footer">
							<?php echo $lang['sn']['degree_desc'][$i['degree_id']];?><br />
							</span>
						</td>
						<td align="center" valign="top" class="bg4" width="10%">
							<?php echo $i['sn_total'];?><br />
						</td>
					</tr>
	
					<?php
					endforeach;
					}
					
					if (isset($sn_statistics['total_pending'])) {
					?>
					<tr>
						<td class="bg3">
							<?php echo $lang['txt_outstanding_invites'];?><br />
							<span class="txt_footer">
							<?php echo $lang['txt_outstanding_invites_intro'];?><br />
							</span>
						</td>
						<td align="center" valign="top" class="bg4">
							<?php echo $sn_statistics['total_pending'];?><br />
						</td>
					</tr>
					<?php 
					}
					
					if (isset($sn_statistics['total'])) {
					?>
					<tr>
						<td class="bg3">
							<?php echo $lang['txt_your_social_network'];?><br />
							<span class="txt_footer">
							<?php echo $lang['txt_your_social_network_intro'];?><br />
							</span>
						</td>
						<td align="center" valign="top" class="bg1">
							<?php echo $sn_statistics['total'];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
	
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
	
				<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture_light">
					<tr>
						<td class="bg3">
							<?php echo $lang['txt_total_online_users'];?>:<br />
						</td>
						<td align="center" valign="top" class="bg4" width="10%">
							<?php echo $sn_statistics['statistics']['total_online_users'];?><br />
						</td>
					</tr>
					<tr>
						<td class="bg3">
							<?php echo $lang['txt_total_users'];?>:<br />
						</td>
						<td align="center" valign="top" class="bg4">
							<?php echo $sn_statistics['statistics']['total_users'];?><br />
						</td>
					</tr>
				</table>
				
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
				
				<table width="100%" cellpadding="4" cellspacing="0" border="0">
					<tr>
						<td>
							<b><?php echo $lang['hdr_tag'];?></b><br />
						</td>
					</tr>
					<tr>
						<td>
							<?php
							$tags = "";
							if (isset($my_tags)) {
								foreach ($my_tags as $key => $i):
									$tags .= "<a href='sn_list.php?tag=" . $i['tag_body']. "'>" . $i['tag_body'] . "</a>, ";
								endforeach;
								
								$tags .= "<a href='sn_list.php'>" . $lang['txt_view_all_network'] . "</a>";
							}
							echo $tags;
							?>
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

==> igloo_0_1_3.tar.tgz: igloo_0_1_3/igloo/template/barnraiser_01/sn_list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>




<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_social_network'];?><br />
		</div>

		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($users)) {
				?>
				<table width="100%" border="0" cellspacing="0" cellpadding="4">
					<?php
					$display_items = trimArray($users);
					foreach($display_items as $key => $i):
					?>
					<tr>
						<td valign="top" width="32" rowspan="2">
							<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
						</td>
							
						<td valign="middle">
							<?php
							if (!empty($i['am_relation_to_them']['relation_show_true_self'])) {
							?>
								<b><a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><?php echo $i['user_firstname']. " " . $i['user_surname'];?></a></b>,
								
								
								<?php echo $this->date->formatDate($i['user_create_datetime']);?>,
								<?php echo $i['user_hometown'];?>,
							<?php
							}
							else {
							?>
							
								<a href="sn_profile.php?user_id=<?php echo $i['user_id'];?>"><b><?php echo $i['profile_nic'];?></b></a>,
								
								
								<?php echo $this->date->formatDate($i['user_create_datetime']);?>,
								<?php echo $i['profile_hometown'];?>,
							<?php }?>
							
							<?php
							if ($i['online_status'] == 1) {
								echo "<b>" . $lang['arr_user_online_status'][1] . "</b><br />";
							}
							else {
									echo $lang['arr_user_online_status'][$i['online_status']] . "<br />";
							}
							?>
						</td>
						
						<td valign="top" width="80">
							<?php
							if (isset($i['relation_to'])) {
								echo "<img src='" . $templatePath . "img/sn_connected_to_them.png' width='16' height='16' title='" .  $lang['txt_help_icon_conn'] . "' alt='" .  $lang['txt_help_icon_conn'] . "' />&nbsp;";
								
								if (!empty($i['relation_to']['relation_show_network'])) {
									echo "<img src='" . $templatePath . "img/sn_they_see_my_nw.png' width='16' height='16' title='" . $lang['txt_help_icon_net'] . "' alt='" . $lang['txt_help_icon_net'] . "' />&nbsp;";
								}
								
								if (!empty($i['relation_to']['relation_show_true_self'])) {
									echo "<img src='" . $templatePath . "img/sn_true_self_revealed_to_them.png' width='16' height='16' title='" . $lang['txt_help_icon_ts'] . "' alt='" . $lang['txt_help_icon_ts'] . "' />&nbsp;";
								}
							}
							?><br />
						</td>
						<td valign="top" align="right" rowspan="2">
							<?php
							if (isset($i['profile_allow_msg']) && $i['profile_allow_msg'] == 1) {
							?>
							<a href="msg_edit.php?to_user_id=<?php echo $i['user_id'];?>"><img src="<?php echo $templatePath;?>img/unopenned_mail.png" title="<?php echo $lang['ttl_send_message'];?>" border="0" alt="" /></a>&nbsp;&nbsp;<br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td>
							<p>
								<?php echo $lang['txt_tag'];?>: 
		
								<?php
								$tags = "";
								if (isset($i['tags'])) {
									foreach ($i['tags'] as $keyt => $t):
										$tags .= $t['tag_body'];
										
										if (count($i['tags']) > $keyt+1) {
											$tags .= ", ";
										}
									endforeach;
									echo $tags;
								}
								?>
							</p>
						</td>
						<td>
							<?php
							if (!empty($i['blocked'])) {
								echo $lang['txt_blocked'] . "<br />";
							}
							?>
							<?php
							if (!empty($i['am_relation_to_them']['relation_show_network'])) {
									echo "relations: " . $i['sn_total'];
								}
							?>
							<br />
						</td>
					</tr>
					<tr>
						<td colspan="4">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="4" alt="" /><br />
						</td>
					</tr>
					<?php
					endforeach;
					?>
				</table>
				<?php
				echo createArrayList($users);
				}
				else {
				?>
				<p>
					<?php echo $lang['err_no_people'];?><br />
				</p>
				<?php }?>
				
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
				
				<table cellpadding="4" cellspacing="0" border="0">
					<tr>
						<td colspan="2">
							<b><?php echo $lang['hdr_im_pending'];?></b><br />
						</td>
					</tr>
					<?php
					if (isset($pending)) {
					foreach($pending as $key => $i):
					?>
					<tr>
						<td>
							<?php echo $this->date->formatDate($i['invite_create_datetime']);?><br />
						</td>
						<td>
							<?php echo $i['email'];?><br />
						</td>
					</tr>
					<?php
					endforeach;
					} else {
					?>
					<tr>
						<td colspan="2">
							<?php echo $lang['err_no_pending_requests'];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_statistics'];?><br />
		</div>

		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_social_network'];?></b><br />
					<?php echo $lang['txt_social_network_intro'];?>
				</p>
	
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
	
				<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture_light">
					<?php
					if (isset($sn_statistics['degrees'])) {
	
					foreach($sn_statistics['degrees'] as $key => $i):
					?>
					<tr>
						<td class="bg3">
							<?php echo $lang['sn']['degree'][$i['degree_id']];?><br />
						</td>
						<td align="center" valign="top" class="bg4" width="10%">
							<?php echo $i['sn_total'];?><br />
						</td>
					</tr>
	
					<?php
					endforeach;
					}
					
					if (isset($sn_statistics['total_pending'])) {
					?>
					<tr>
						<td class="bg3">
							<?php echo $lang['txt_outstanding_invites'];?><br />
						</td>
						<td align="center" valign="top" class="bg4">
							<?php echo $sn_statistics['total_pending'];?><br />
						</td>
					</tr>
					<?php 
					}
					
					if (isset($sn_statistics['total'])) {
					?>
					<tr>
						<td class="bg3">
							<?php echo $lang['txt_your_social_network'];?><br />
						</td>
						<td align="center" valign="top" class="bg1">
							<?php echo $sn_statistics['total'];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
	
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />
	
				<table width="100%" border="0" cellspacing="2" cellpadding="2" class="picture_light">
					<tr>
						<td class="bg3">
							<?php echo $lang['txt_total_online_users'];?>:<br />
						</td>
						<td align="center" valign="top" class="bg4" width="10%">
							<?php echo $sn_statistics['statistics']['total_online_users'];?><br />
						</td>
					</tr>
					<tr>
						<td class="bg3">
							<?php echo $lang['txt_total_users'];?>:<br />
						</td>
						<td align="center" valign="top" class="bg4">
							<?php echo $sn_statistics['statistics']['total_users'];?><br />
						</td>
					</tr>
				</table>
				
				<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
				
				<table width="100%" cellpadding="4" cellspacing="0" border="0">
					<tr>
						<td>
							<b><?php echo $lang['hdr_tag'];?></b><br />
						</td>
					</tr>
					<tr>
						<td>
							<?php
							$tags = "";
							if (isset($my_tags)) {
								foreach ($my_tags as $key => $i):
									$tags .= "<a href='sn_list.php?tag=" . $i['tag_body']. "'>" . $i['tag_body'] . "</a>, ";
								endforeach;
								
								$tags .= "<a href='sn_list.php'>" . $lang['txt_view_all_network'] . "</a>";
							}
							echo $tags;
							?>
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
		
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
